# COPR Ligenix's spec file for glpi-plugin-glpiinventory
#
# Copyright (c) 2021-2022 Jean-Marc Liger
#
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global pluginname glpiinventory
%global glpi_min   10.0.2
%global glpi_max   10.1.0

Name:           glpi-plugin-%{pluginname}
Version:        1.0.6
Release:        1%{?dist}
Summary:        Plugin to handle various types of tasks for GLPI agents

License:        AGPLv3+
URL:            https://github.com/glpi-project/glpi-inventory-plugin

Source0:        https://github.com/glpi-project/glpi-inventory-plugin/releases/download/%{version}/glpi-%{pluginname}-%{version}.tar.bz2

BuildArch:      noarch

%if 0%{?fedora} || 0%{?rhel} >= 8
Requires:      (glpi >= %{glpi_min} with glpi < %{glpi_max})
%else
Requires:       glpi >= %{glpi_min}
Requires:       glpi <  %{glpi_max}
%endif


%description
Plugin to handle various types of tasks for GLPI agents:
- Network discovery and inventory (SNMP)
- Software deployment
- VMWare ESX host remote inventory
- Collect data (files, Windows registry, WMI)

Computer and Network inventories themselves are done on GLPI side; the plugin only handle network related tasks.


%prep
%setup -q -c

grep "define('PLUGIN_GLPI_INVENTORY_GLPI_M.._VERSION" %{pluginname}/setup.php

# remove unused files
rm    %{pluginname}/{.,}*.xml
rm    %{pluginname}/composer.json
rm -r %{pluginname}/vendor

# move doc files
mkdir docs
mv %{pluginname}/README*.md docs/

# Create link to LICENSE for standard doc folder
ln -s %{_datadir}/glpi/plugins/%{pluginname}/LICENSE LICENSE


%build
# empty build


%install
mkdir -p %{buildroot}%{_localstatedir}/lib/glpi/files/_plugins/%{pluginname}

mkdir -p %{buildroot}/%{_datadir}/glpi/plugins
cp -ar %{pluginname} %{buildroot}/%{_datadir}/glpi/plugins/%{pluginname}

for i in %{buildroot}/%{_datadir}/glpi/plugins/%{pluginname}/locales/*
do
  lang=$(basename $i)
  echo "%lang(${lang:0:2}) %{_datadir}/glpi/plugins/%{pluginname}/locales/${lang}"
done | tee %{name}.lang


%files -f %{name}.lang
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc docs/*
%dir %{_datadir}/glpi/plugins/%{pluginname}
%dir %{_datadir}/glpi/plugins/%{pluginname}/locales
# LICENSE file required by installation process
%{_datadir}/glpi/plugins/%{pluginname}/LICENSE
%{_datadir}/glpi/plugins/%{pluginname}/*.php
%{_datadir}/glpi/plugins/%{pluginname}/ajax
%{_datadir}/glpi/plugins/%{pluginname}/b
%{_datadir}/glpi/plugins/%{pluginname}/css
%{_datadir}/glpi/plugins/%{pluginname}/front
%{_datadir}/glpi/plugins/%{pluginname}/inc
%{_datadir}/glpi/plugins/%{pluginname}/install
%{_datadir}/glpi/plugins/%{pluginname}/js
%{_datadir}/glpi/plugins/%{pluginname}/lib
%{_datadir}/glpi/plugins/%{pluginname}/pics
%{_datadir}/glpi/plugins/%{pluginname}/report
%{_datadir}/glpi/plugins/%{pluginname}/templates
# data
%attr(750,apache,root) %{_localstatedir}/lib/glpi/files/_plugins/%{pluginname}


%changelog
* Mon Dec 12 2022 Jean-Marc Liger <ligenix@iscp.fr> - 1.0.6-1
- Update to 1.0.6

* Mon Nov 14 2022 Jean-Marc Liger <ligenix@iscp.fr> - 1.0.5-1
- Update to 1.0.5
- Correct Licence

* Thu Sep 15 2022 Jean-Marc Liger <ligenix@iscp.fr> - 1.0.4-1
- Update to 1.0.4

* Sat Jul 30 2022 Jean-Marc Liger <ligenix@iscp.fr> - 1.0.3-2
- Correct URL

* Sat Jul 30 2022 Jean-Marc Liger <ligenix@iscp.fr> - 1.0.3-1
- Version 1.0.3 for GLPI 10.0.x
- Initial RPM based on Remi Collet previous GLPI plugins spec files
